// LICENSE : MIT
"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.getEntries = getEntries;
exports.dayOneToQuiver = dayOneToQuiver;

var _DayOneEntry = require("./DayOneEntry");

var _DayOneEntry2 = _interopRequireDefault(_DayOneEntry);

var _QuiverEntryBuilder = require("./QuiverEntryBuilder");

var _QuiverEntryBuilder2 = _interopRequireDefault(_QuiverEntryBuilder);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var fs = require("fs");
var path = require("path");
var plist = require("plist");
var mkdirp = require("mkdirp");

/**
 *
 * @param {string} dayOneFilePath
 * @returns
 */
function getEntries(dayOneFilePath) {
    var entryDir = path.join(dayOneFilePath, "entries");
    var entriesFilePathList = fs.readdirSync(entryDir);
    return entriesFilePathList.map(function (filePath) {
        var entryXML = fs.readFileSync(path.join(entryDir, filePath), "utf-8");
        var entryJSON = plist.parse(entryXML);
        return new _DayOneEntry2.default(entryJSON);
    });
}

function dayOneToQuiver(dayOneFilePath, outputDir) {
    var entries = getEntries(dayOneFilePath);
    /*
    B59AC519-2A2C-4EC8-B701-E69F54F40A85.qvnote/
    ├── content.json
    ├── meta.json
     */
    entries.filter(function (entry) {
        return !entry.isFragment;
    }).forEach(function (entry) {
        var builder = new _QuiverEntryBuilder2.default(entry);
        var qvnoteDir = path.join(outputDir, entry.uuid + ".qvnote");
        // create dir
        mkdirp.sync(qvnoteDir);
        // create meta
        fs.writeFileSync(path.join(qvnoteDir, 'meta.json'), JSON.stringify(builder.toMeta(), null, 2));
        // create content
        fs.writeFileSync(path.join(qvnoteDir, 'content.json'), JSON.stringify(builder.toContent(), null, 2));
    });
}
//# sourceMappingURL=dayone-to-quiver.js.map